
import { MainPage } from 'apps/admin-e2e/src/page-objects/main.po';
import { BenutzerE2EComponent } from '../../../components/benutzer/benutzer.e2e.component';
import { beChecked, beEnabled, contains, exist, notBeChecked, notBeEnabled } from '../../../support/cypress.util';
import { AlfaRollen, AlfaUsers, loginAsAriane } from '../../../support/user-util';
import { SnackBarE2EComponent } from '../../../components/ui/snackbar.e2e.component';
import { SnackbarMessagesE2E } from '../../../model/util';
import { getCypressEnv, interceptWithResponse, wait, waitOfInterceptor } from 'apps/admin-e2e/src/support/cypress-helper';
import { AdminUserE2E, HttpMethodE2E } from '../../../model/util';

const mainPage: MainPage = new MainPage();
const benutzerPage: BenutzerE2EComponent = new BenutzerE2EComponent();
const snackBar: SnackBarE2EComponent = new SnackBarE2EComponent();

const vorname: string = 'Theo';
const nachname: string = 'Testuser';
const benutzername: string = 'testtheo';
const emailAddress: string = 'theo.test@ozg-sh.de';

const newUser: AdminUserE2E = {
  vorname: 'Theo',
  nachname: 'Testuser',
  benutzername: 'testtheo',
  email: 'theo.test@ozg-sh.de',
  isAdmin: true,
  isUser: true,
}

describe('Benutzer anlegen', () => {
  before(() => {
    loginAsAriane();
  });

  it('should open Benutzer tab and show Hinzufuegen button', () => {
    mainPage.clickBenutzerNavigationItem();

    exist(benutzerPage.getHinzufuegenButton());
  });

  it('should show snackbar message on error', () => {
    const interceptor: string = 'postUser';
    const url: string = getCypressEnv('keycloakUrl') + '/admin/realms/' + getCypressEnv('keycloakRealm') + '/users'
    const errorCode: number = 500;
    const errorBody: string = 'Internal Server Error';

    interceptWithResponse(HttpMethodE2E.POST, url, { errorCode, errorBody }).as(interceptor);

    benutzerPage.clickAddUser();
    benutzerPage.addUser(newUser); 

    waitOfInterceptor(interceptor).then(() => {
      contains(snackBar.getMessage(), SnackbarMessagesE2E.NUTZER_FEHLGESCHLAGEN);
    });
  });

  it('should show snackbar message on saving user', () => {
    snackBar.getCloseButton().click();

    benutzerPage.saveUser();
    contains(snackBar.getMessage(), SnackbarMessagesE2E.NUTZER_ANGELEGT);
  });

  it('should display new user in users table', () => {
    benutzerPage.stringExistsInUserEntry(AlfaRollen.USER, benutzername);
    benutzerPage.stringExistsInUserEntry(vorname, benutzername);
    benutzerPage.stringExistsInUserEntry(nachname, benutzername);
    // FEHLT NOCH: benutzerPage.stringExistsInUserEntry(AlfaRollen.ADMIN, benutzername);
  });
});
