/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { OrganisationsEinheitenE2EComponent } from '../../../components/organisationseinheiten/organisationseinheiten.e2e.component';
import { MainPage, waitForSpinnerToDisappear } from '../../../page-objects/main.po';
import { exist } from '../../../support/cypress.util';
import { OrganisationsEinheitSyncResultE2E } from '../../../support/organisationseinheit';
import {
  createBauamtOrganisationsEinheit,
  createDenkmalpflegeOrganisationsEinheit,
  createFundstelleOrganisationsEinheit,
  initOrganisationsEinheiten,
} from '../../../support/organisationseinheit-util';
import { loginAsAriane } from '../../../support/user-util';

describe.skip('TODO: activate after fix for OZG-7391: show Organisationsheiten', () => {
  const mainPage: MainPage = new MainPage();
  const organisationsEinheitenTab: OrganisationsEinheitenE2EComponent = new OrganisationsEinheitenE2EComponent();

  before(() => {
    loginAsAriane();
    initOrganisationsEinheiten([
      createBauamtOrganisationsEinheit(),
      { ...createDenkmalpflegeOrganisationsEinheit(), syncResult: OrganisationsEinheitSyncResultE2E.NAME_MISMATCH },
      { ...createFundstelleOrganisationsEinheit(), syncResult: OrganisationsEinheitSyncResultE2E.NOT_FOUND_IN_PVOG },
    ]);
  });

  it('should show table of Organisationseinheiten', () => {
    waitForSpinnerToDisappear();
    mainPage.clickOrganisationsEinheitenNavigationItem();

    exist(organisationsEinheitenTab.getOrganisationsEinheitList());
  });

  it('should show identical data in Keycloak and PVOG without error', () => {
    organisationsEinheitenTab.getListItemByName('Bauamt');
    organisationsEinheitenTab.organisationsEinheitContainsID('Bauamt', '248240886');
    organisationsEinheitenTab.elementShowsNoError('Bauamt');
  });

  it('should show data not found in PVOG in red color and with error icon and tooltip message', () => {
    const organisationsEinheitName: string = 'Fundstelle';

    organisationsEinheitenTab.organisationsEinheitContainsID(organisationsEinheitName, '10363455');
    organisationsEinheitenTab.elementIsShownAsError(organisationsEinheitName);
    organisationsEinheitenTab.getErrorIconInElement(organisationsEinheitName);
    organisationsEinheitenTab.getErrorTooltip(organisationsEinheitName);
  });

  it('should get name for OE from PVOG, if mismatch with Keycloak, but without error', () => {
    organisationsEinheitenTab.organisationsEinheitContainsID('Landesamt für Denkmalpflege', '9093371');
    organisationsEinheitenTab.elementShowsNoError('Landesamt für Denkmalpflege');
  });
});
