/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { registerLocaleData } from '@angular/common';
import localeDe from '@angular/common/locales/de';
import localeDeExtra from '@angular/common/locales/extra/de';
import { VorgangBescheidWizardE2EComponent } from 'apps/alfa-e2e/src/components/vorgang/vorgang-bescheid-wizard.e2e.component';
import { VorgangBescheideE2EComponent } from 'apps/alfa-e2e/src/components/vorgang/vorgang-bescheide.e2e.component';
import { VorgangFormularButtonsE2EComponent } from 'apps/alfa-e2e/src/components/vorgang/vorgang-formular-buttons.e2e.components';
import { VorgangFormularDatenE2EComponent } from 'apps/alfa-e2e/src/components/vorgang/vorgang-formular.e2e.component';
import { VorgangSubnavigationE2EComponent } from 'apps/alfa-e2e/src/components/vorgang/vorgang-subnavigation';
import { BescheidHistorieItemE2EComponent, VorgangFormularDatenHistorieItemE2EComponent, } from 'apps/alfa-e2e/src/components/vorgang/vorgang.formular-daten.historie.e2e.component';
import { HistorieHeadlineE2E } from 'apps/alfa-e2e/src/model/historie';
import { VorgangE2E, VorgangStatusE2E } from 'apps/alfa-e2e/src/model/vorgang';
import { TEST_FILE_BESCHEID_ANHANG_VALID, TEST_FILE_BESCHEID_VALID } from 'apps/alfa-e2e/src/support/data.util';
import { uploadFile } from 'apps/alfa-e2e/src/support/file-upload';
import { getAdjustedDateGerman } from 'apps/alfa-e2e/src/support/tech.util';
import 'cypress-real-events/support';
import { VorgangListE2EComponent } from '../../../components/vorgang/vorgang-list.e2e.component';
import { MainPage, waitForSpinnerToDisappear } from '../../../page-objects/main.po';
import { VorgangPage } from '../../../page-objects/vorgang.po';
import { dropCollections } from '../../../support/cypress-helper';
import { contains, enterWith, exist, notExist } from '../../../support/cypress.util';
import { getUserSabine, initUsermanagerUsers, loginAsSabine } from '../../../support/user-util';
import { buildVorgang, initVorgaenge, objectIds } from '../../../support/vorgang-util';

registerLocaleData(localeDe, 'de', localeDeExtra);

describe('Bescheid History', () => {
  const mainPage: MainPage = new MainPage();
  const vorgangList: VorgangListE2EComponent = mainPage.getVorgangList();

  const bewilligtText: string = 'Bewilligt am';
  const abgelehntText: string = 'Abgelehnt am';
  const einAnhangText: string = 'Es existiert ein Anhang';
  const zweiAnhaengeText: string = 'Es existieren 2 Anhänge';

  const vorgangPage: VorgangPage = new VorgangPage();
  const bescheidWizard: VorgangBescheidWizardE2EComponent = vorgangPage.getBescheidWizard();

  const bescheidSpeichernVorgang: VorgangE2E = {
    ...buildVorgang(objectIds[0], 'Bescheid speichern Vorgang'),
    status: VorgangStatusE2E.IN_BEARBEITUNG,
  };

  const bescheidSingleVorgang: VorgangE2E = {
    ...buildVorgang(objectIds[1], 'Bescheid ohne Attachment Vorgang'),
    status: VorgangStatusE2E.IN_BEARBEITUNG,
  };

  const bescheidSendenVorgang: VorgangE2E = {
    ...buildVorgang(objectIds[2], 'Bescheid senden Vorgang'),
    status: VorgangStatusE2E.IN_BEARBEITUNG,
  };

  const vorgangDatenFormular: VorgangFormularDatenE2EComponent = vorgangPage.getFormularDatenContainer();

  const vorgangFormularButtons: VorgangFormularButtonsE2EComponent = vorgangPage.getFormularButtons();

  const vorgangSubnavigationButtons: VorgangSubnavigationE2EComponent = vorgangPage.getSubnavigation();

  const bescheide: VorgangBescheideE2EComponent = vorgangPage.getBescheide();

  before(() => {
    initVorgaenge([bescheidSpeichernVorgang, bescheidSingleVorgang, bescheidSendenVorgang]);
    initUsermanagerUsers();

    loginAsSabine();

    waitForSpinnerToDisappear();
    exist(vorgangList.getRoot());
  });

  after(() => {
    dropCollections();
  });

  describe('Show Bescheid notes in history', () => {
    const userName: string = `${getUserSabine().firstName} ${getUserSabine().lastName}`;

    describe('Show history entry after saving Bescheid', () => {
      it('should show Bescheid entry on history tab after saving', () => {
        vorgangList.getListItem(bescheidSpeichernVorgang.name).getRoot().click();
        waitForSpinnerToDisappear();

        vorgangFormularButtons.getBescheidenButton().click();
        enterWith(bescheidWizard.getDateInput(), getAdjustedDateGerman(-1));
        bescheidWizard.getWeiterButton().click();
        uploadFile(bescheidWizard.getUploadBescheidButton(), TEST_FILE_BESCHEID_VALID);
        notExist(bescheidWizard.getBescheidUploadSpinner());
        uploadFile(bescheidWizard.getUploadAttachmentButton(), TEST_FILE_BESCHEID_ANHANG_VALID);
        notExist(bescheidWizard.getAttachmentUploadSpinner());
        bescheidWizard.getWeiterButton().click();
        bescheidWizard.getSaveButton().click();
        bescheidWizard.getConfirmAndSaveButton().click();
        waitForSpinnerToDisappear();
        vorgangDatenFormular.getHistorieTab().click();

        const historieItem: VorgangFormularDatenHistorieItemE2EComponent = vorgangDatenFormular.getHistorieItemByIndex(0);

        contains(historieItem.getHeadline(), HistorieHeadlineE2E.BESCHEID_ERSTELLT);
        contains(historieItem.getUser(), userName);
      });

      it('should show detailed info after click on arrow', () => {
        const historieItem: VorgangFormularDatenHistorieItemE2EComponent = vorgangDatenFormular.getHistorieItemByIndex(0);
        const bescheidItem: BescheidHistorieItemE2EComponent = historieItem.getBescheid();
        historieItem.getExpandButton().click();

        contains(bescheidItem.getStatus(), bewilligtText);
        contains(bescheidItem.getStatus(), getAdjustedDateGerman(-1));
        exist(bescheidItem.getBescheidDokumentText());
        contains(bescheidItem.getBescheidAnhaengeText(), einAnhangText);
      });

      it('should show single text for Bescheid without attachment', () => {
        vorgangSubnavigationButtons.getBackButton().click();
        vorgangList.getListItem(bescheidSingleVorgang.name).getRoot().click();
        waitForSpinnerToDisappear();

        vorgangFormularButtons.getBescheidenButton().click();
        enterWith(bescheidWizard.getDateInput(), getAdjustedDateGerman(-1));
        bescheidWizard.getWeiterButton().click();
        uploadFile(bescheidWizard.getUploadBescheidButton(), TEST_FILE_BESCHEID_VALID);
        notExist(bescheidWizard.getBescheidUploadSpinner());
        bescheidWizard.getWeiterButton().click();
        bescheidWizard.getSaveButton().click();
        bescheidWizard.getConfirmAndSaveButton().click();
        waitForSpinnerToDisappear();
        vorgangDatenFormular.getHistorieTab().click();

        const historieItem: VorgangFormularDatenHistorieItemE2EComponent = vorgangDatenFormular.getHistorieItemByIndex(0);
        const bescheidItem: BescheidHistorieItemE2EComponent = historieItem.getBescheid();
        historieItem.getExpandButton().click();

        contains(bescheidItem.getStatus(), bewilligtText);
        contains(bescheidItem.getStatus(), getAdjustedDateGerman(-1));
        exist(bescheidItem.getBescheidDokumentText());
        notExist(bescheidItem.getBescheidAnhaengeText());
      });
    });

    describe('Show history entry after sending Bescheid', () => {
      it('should show Bescheid entry on history tab after sending message', () => {
        vorgangSubnavigationButtons.getBackButton().click();
        vorgangList.getListItem(bescheidSendenVorgang.name).getRoot().click();
        waitForSpinnerToDisappear();

        vorgangFormularButtons.getBescheidenButton().click();
        bescheidWizard.getAbgelehntButton().click();
        enterWith(bescheidWizard.getDateInput(), getAdjustedDateGerman(1));
        bescheidWizard.getWeiterButton().click();
        uploadFile(bescheidWizard.getUploadBescheidButton(), TEST_FILE_BESCHEID_VALID);
        notExist(bescheidWizard.getBescheidUploadSpinner());
        uploadFile(bescheidWizard.getUploadAttachmentButton(), TEST_FILE_BESCHEID_ANHANG_VALID);
        notExist(bescheidWizard.getAttachmentUploadSpinner());
        uploadFile(bescheidWizard.getUploadAttachmentButton(), TEST_FILE_BESCHEID_ANHANG_VALID);
        notExist(bescheidWizard.getAttachmentUploadSpinner());
        bescheidWizard.getWeiterButton().click();
        bescheidWizard.getSendButton().click();
        exist(bescheidWizard.getSendenSpinner());
        notExist(bescheidWizard.getSendenSpinner());

        vorgangDatenFormular.getHistorieTab().click();
        const historieItemExpand: VorgangFormularDatenHistorieItemE2EComponent = vorgangDatenFormular.getHistorieItemByIndex(0);
        const bescheidItem: BescheidHistorieItemE2EComponent = historieItemExpand.getBescheid();
        historieItemExpand.getExpandButton().click();

        contains(bescheidItem.getStatus(), abgelehntText);
        contains(bescheidItem.getStatus(), getAdjustedDateGerman(1));
        exist(bescheidItem.getBescheidDokumentText());
        contains(bescheidItem.getBescheidAnhaengeText(), zweiAnhaengeText);
      });

      it('should show history entries for sent Bescheid and message', () => {
        const historieItemSent: VorgangFormularDatenHistorieItemE2EComponent = vorgangDatenFormular.getHistorieItemByIndex(1);
        contains(historieItemSent.getHeadline(), HistorieHeadlineE2E.BESCHEID_VERSCHICKT);
        contains(historieItemSent.getUser(), userName);

        const historieItemMessage: VorgangFormularDatenHistorieItemE2EComponent = vorgangDatenFormular.getHistorieItemByIndex(3);
        contains(historieItemMessage.getHeadline(), HistorieHeadlineE2E.SEND_POSTFACH_NACHRICHT);
        contains(historieItemMessage.getUser(), userName);
      });
    });
  });
});
