import { registerLocaleData } from '@angular/common';
import localeDe from '@angular/common/locales/de';
import localeDeExtra from '@angular/common/locales/extra/de';
import { SnackBarE2EComponent } from 'apps/alfa-e2e/src/components/ui/snackbar.e2e.component';
import { VorgangFormularButtonsE2EComponent } from 'apps/alfa-e2e/src/components/vorgang/vorgang-formular-buttons.e2e.components';
import {
  VorgangMoreMenuArchivierenItemE2EComponent,
  VorgangMoreMenuE2EComponent,
} from 'apps/alfa-e2e/src/components/vorgang/vorgang-more-menu.e2e.components';
import { VorgangSubnavigationE2EComponent } from 'apps/alfa-e2e/src/components/vorgang/vorgang-subnavigation';
import { VorgangListE2EComponent } from '../../../components/vorgang/vorgang-list.e2e.component';
import { VorgangE2E, VorgangStatusE2E } from '../../../model/vorgang';
import { MainPage, waitForSpinnerToDisappear } from '../../../page-objects/main.po';
import { VorgangPage } from '../../../page-objects/vorgang.po';
import { dropCollections, wait } from '../../../support/cypress-helper';
import { exist, notExist } from '../../../support/cypress.util';
import { loginAsSabine } from '../../../support/user-util';
import { createVorgang, initVorgaenge } from '../../../support/vorgang-util';

registerLocaleData(localeDe, 'de', localeDeExtra);

describe('Vorgang archivieren', () => {
  const mainPage: MainPage = new MainPage();
  const snackBar: SnackBarE2EComponent = mainPage.getSnackBar();

  const vorgangList: VorgangListE2EComponent = mainPage.getVorgangList();

  const vorgangPage: VorgangPage = new VorgangPage();
  const subnavigation: VorgangSubnavigationE2EComponent = vorgangPage.getSubnavigation();
  const vorgangMoreMenu: VorgangMoreMenuE2EComponent = vorgangPage.getMoreMenu();

  const vorgangFormularButtons: VorgangFormularButtonsE2EComponent = vorgangPage.getFormularButtons();

  const vorgangExportieren: VorgangE2E = {
    ...createVorgang(),
    status: VorgangStatusE2E.ABGESCHLOSSEN,
    name: 'DoArchivieren',
  };

  before(() => {
    initVorgaenge([vorgangExportieren]);

    loginAsSabine();

    waitForSpinnerToDisappear();
    exist(vorgangList.getRoot());
  });

  after(() => {
    dropCollections();
  });

  describe('archive file', () => {
    const archivierenItem: VorgangMoreMenuArchivierenItemE2EComponent = vorgangMoreMenu.getArchivierenItem();

    it('should not show archived status on list page', () => {
      notExist(vorgangList.getArchivedStatus());
    });

    it('Open Vorgang-Detail-Page', () => {
      vorgangList.getListItem(vorgangExportieren.name).getRoot().click();
      waitForSpinnerToDisappear();

      exist(vorgangPage.getVorgangDetailHeader().getRoot());
    });

    it('should show "Archivieren" button in Abgeschlossen status', () => {
      vorgangMoreMenu.getButton().click();

      exist(archivierenItem.getButton());
    });

    it('should open popup with confirm button on clicking "Vorgang archivieren"', () => {
      archivierenItem.clickArchivieren();

      exist(archivierenItem.getArchivierenConfirm());
    });

    it('should close popup on clicking Cancel', () => {
      archivierenItem.cancelArchivieren();

      notExist(archivierenItem.getArchivierenConfirm());
    });

    it('should open popup again and archive Vorgang on confirmation', () => {
      vorgangMoreMenu.getButton().click();
      archivierenItem.clickArchivieren();
      archivierenItem.confirmArchivieren();

      //ersetzen, sobald tatsächliche Archivierung geklärt ist; aktuell nur Workaround
      wait(2000);
      archivierenItem.cancelArchivieren();
      //
    });

    it('should show archived status on list page', () => {
      subnavigation.getBackButton().click({ force: true });
      waitForSpinnerToDisappear();

      exist(vorgangList.getArchivedStatus());
    });

    it('should still show back button on details page', () => {
      vorgangList.getListItem(vorgangExportieren.name).getRoot().click();
      waitForSpinnerToDisappear();

      exist(subnavigation.getBackButton());
    });

    it('should not show subnavigation buttons on details page', () => {
      notExist(subnavigation.getCreateWiedervorlageIconButton());
      notExist(subnavigation.getAssignUserProfileIconButton());
      notExist(subnavigation.getPostfachMailIconButton());
    });
  });
});
