import { Db, MongoClient } from 'mongodb';

export function insertWithDrop(databaseUrl: string, databaseName: string, collection: string, data): void {
  connectoToDb(databaseUrl, databaseName, async (database: Db) => {
    try {
      console.log('drop collection and insert data');
      await database.dropCollection(collection);
      await database.collection(collection).insertMany(data);
    } catch (error) {
      console.error('Failed to insert data: ', error);
    }
  });
}

export async function insert(databaseUrl: string, databaseName: string, collection: string, data): Promise<void> {
  connectoToDb(databaseUrl, databaseName, async (database: Db) => {
    try {
      console.log('insert data');
      await database.collection(collection).insertMany(data);
    } catch (error) {
      console.error('Failed to insert data: ', error);
    }
  });
}

export function dropCollections(databaseUrl: string, databaseName: string, collections: string[]): void {
  connectoToDb(databaseUrl, databaseName, async (database: Db) => {
    for (let collection of collections) {
      await dropCollection(database, collection);
    }
  });
}

async function dropCollection(database: Db, collection: string): Promise<void> {
  try {
    console.log('drop collection', collection);
    await database.collection(collection).drop();
  } catch (err) {
    console.warn(`Failed to drop collection ${collection}:`, err.message);
  }
}

async function connectoToDb(databaseUrl: string, databaseName: string, execution: (database: Db) => void): Promise<void> {
  const client: MongoClient = new MongoClient(databaseUrl);
  try {
    console.log('open db connection');
    const client: MongoClient = await MongoClient.connect(databaseUrl);
    const database: Db = client.db(databaseName);
    await execution(database);
  } catch (error) {
    console.error('Error:', error);
  } finally {
    console.log('close db connection');
    await client.close();
  }
}
