/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { User } from '@admin-client/user-shared';
import { StateResource } from '@alfa-client/tech-shared';
import { AsyncPipe } from '@angular/common';
import { Component, inject, OnInit } from '@angular/core';
import { FormsModule, ReactiveFormsModule } from '@angular/forms';
import { SpinnerComponent } from '@ods/component';
import { Observable } from 'rxjs';
import { UserFormDataComponent } from './user-form-data/user-form-data.component';
import { UserFormDeleteButtonContainerComponent } from './user-form-delete-button/user-form-delete-button-container.component';
import { UserFormHeadlineComponent } from './user-form-headline/user-form-headline.component';
import { UserFormOrganisationsEinheitListComponent } from './user-form-organisations-einheit-list/user-form-organisations-einheit-list.component';
import { UserFormRolesComponent } from './user-form-roles/user-form-roles.component';
import { UserFormSaveButtonComponent } from './user-form-save-button/user-form-save-button.component';
import { UserFormService } from './user.formservice';

@Component({
  selector: 'admin-user-form',
  providers: [UserFormService],
  templateUrl: './user-form.component.html',
  standalone: true,
  imports: [
    FormsModule,
    ReactiveFormsModule,
    AsyncPipe,
    SpinnerComponent,
    UserFormDataComponent,
    UserFormRolesComponent,
    UserFormOrganisationsEinheitListComponent,
    UserFormHeadlineComponent,
    UserFormSaveButtonComponent,
    UserFormDeleteButtonContainerComponent,
  ],
})
export class UserFormComponent implements OnInit {
  public readonly formService = inject(UserFormService);

  public userStateResource$: Observable<StateResource<User>>;

  ngOnInit(): void {
    this.userStateResource$ = this.formService.get();
  }
}
