import { getElementFromFixture } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { faker } from '@faker-js/faker/locale/de';
import { UserOrganisationsEinheitenComponent } from './user-organisations-einheiten.component';

describe('UserOrganisationsEinheitenComponent', () => {
  let component: UserOrganisationsEinheitenComponent;
  let fixture: ComponentFixture<UserOrganisationsEinheitenComponent>;

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      imports: [UserOrganisationsEinheitenComponent],
    }).compileComponents();

    fixture = TestBed.createComponent(UserOrganisationsEinheitenComponent);
    component = fixture.componentInstance;
    component.organisationsEinheiten = [];
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('template', () => {
    describe('list', () => {
      it('should not exist if organisationsEinheiten is empty', () => {
        const list: HTMLElement = getElementFromFixture(fixture, 'ul');
        expect(list).toBeFalsy();
      });

      it('should exist if organisationsEinheiten is not empty', () => {
        component.organisationsEinheiten = [faker.word.sample()];

        fixture.detectChanges();

        const list: HTMLElement = getElementFromFixture(fixture, 'ul');
        expect(list).toBeTruthy();
      });

      it('should show first three organisations einheiten', () => {
        component.organisationsEinheiten = Array.from({ length: 4 }, faker.word.sample);

        fixture.detectChanges();

        const list: HTMLElement = getElementFromFixture(fixture, 'ul');
        expect(list.children.length).toBe(3);
      });

      it('should show "und 1 weiterer" for four organisations einheiten', () => {
        component.organisationsEinheiten = Array.from({ length: 4 }, faker.word.sample);

        fixture.detectChanges();

        const text: HTMLElement = getElementFromFixture(fixture, 'p');
        expect(text.textContent).toBe('und 1 weiterer');
      });

      it('should show "und #Anzahl weitere" for more then four organisations einheiten', () => {
        component.organisationsEinheiten = Array.from({ length: 5 }, faker.word.sample);

        fixture.detectChanges();

        const text: HTMLElement = getElementFromFixture(fixture, 'p');
        expect(text.textContent).toBe('und 2 weitere');
      });
    });

    it('should show text if organisationsEinheiten is empty', () => {
      const text: HTMLElement = getElementFromFixture(fixture, 'p');
      expect(text).toBeTruthy();
    });
  });
});
