import { BescheidResource, BescheidSendBy, BescheidWizardStep, Wizard } from '@alfa-client/bescheid-shared';
import { existsAsHtmlElement, getElementComponentFromFixtureByCss, mock, Mock, triggerEvent } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { MockComponent } from 'ng-mocks';
import { of } from 'rxjs';
import { BescheidService2 } from '../../../../../../bescheid-shared/src/lib/bescheid2.service';
import { createBescheidResource, createWizard } from '../../../../../../bescheid-shared/src/test/bescheid';
import { getDataTestIdOf } from '../../../../../../tech-shared/test/data-test';
import { singleColdCompleted } from '../../../../../../tech-shared/test/marbles';
import { StepContentLayoutComponent } from '../step-content-layout/step-content-layout.component';
import { BescheidWizardStepTitleComponent } from '../step-title/bescheid-wizard-step-title.component';
import { BescheidWizardSummaryComponent } from '../summary/bescheid-wizard-summary.component';
import { BescheidWizardBescheidVersendenContainerComponent } from './bescheid-wizard-bescheid-versenden-container.component';
import { BescheidWizardBescheidVersendenFormComponent } from './form/bescheid-wizard-bescheid-versenden-form.component';
import { BescheidWizardBescheidVersendenSummaryComponent } from './summary/bescheid-wizard-bescheid-versenden-summary.component';

describe('BescheidWizardBescheidVersendenComponent', () => {
  let component: BescheidWizardBescheidVersendenContainerComponent;
  let fixture: ComponentFixture<BescheidWizardBescheidVersendenContainerComponent>;

  const stepContentLayout: string = getDataTestIdOf('step-content-layout');
  const antragBescheidenStepTitleTestId: string = getDataTestIdOf('antrag-bescheiden-step-title');
  const dokumenteHochladenStepTitleTestId: string = getDataTestIdOf('dokumente-hochladen-step-title');
  const formTestId: string = getDataTestIdOf('bescheid-wizard-bescheid-versenden-form');
  const versendenSummaryTestId: string = getDataTestIdOf('bescheiden-result');

  const bescheidResource: BescheidResource = createBescheidResource();

  let bescheidService: Mock<BescheidService2>;

  beforeEach(() => {
    bescheidService = mock(BescheidService2);
  });

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        BescheidWizardBescheidVersendenContainerComponent,
        MockComponent(StepContentLayoutComponent),
        MockComponent(BescheidWizardStepTitleComponent),
        MockComponent(BescheidWizardBescheidVersendenFormComponent),
        MockComponent(BescheidWizardSummaryComponent),
        MockComponent(BescheidWizardBescheidVersendenSummaryComponent),
      ],
      providers: [{ provide: BescheidService2, useValue: bescheidService }],
    }).compileComponents();

    createComponent();
  });

  function createComponent() {
    fixture = TestBed.createComponent(BescheidWizardBescheidVersendenContainerComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  }

  describe('component', () => {
    it('should create', () => {
      expect(component).toBeTruthy();
    });

    it('should set initial values', () => {
      const wizard: Wizard = createWizard();
      bescheidService.getWizard.mockReturnValue(of(wizard));

      createComponent();

      expect(component.wizard$).toBeObservable(singleColdCompleted(wizard));
    });

    it('should set bescheid resource', () => {
      component.bescheidResource = bescheidResource;

      expect(component.bescheidResource).toEqual(bescheidResource);
    });

    it('should set send by', () => {
      component.bescheidResource = bescheidResource;

      expect(bescheidService.setSendBy).toHaveBeenCalledWith(bescheidResource.sendBy);
    });

    describe('onSendBy', () => {
      it('should call service', () => {
        component.onSendBy(BescheidSendBy.MANUAL);

        expect(bescheidService.setSendBy).toHaveBeenCalledWith(BescheidSendBy.MANUAL);
      });
    });

    describe('onStepChange', () => {
      it('should call service', () => {
        component.onStepChange(BescheidWizardStep.DokumenteHochladen);

        expect(bescheidService.setActiveStep).toHaveBeenCalledWith(BescheidWizardStep.DokumenteHochladen);
      });
    });
  });

  describe('template', () => {
    describe('step content layout', () => {
      describe('output', () => {
        describe('stepChange', () => {
          it('should call handler', () => {
            component.onStepChange = jest.fn();

            triggerEvent({
              fixture,
              elementSelector: stepContentLayout,
              name: 'stepChange',
              data: BescheidWizardStep.DokumenteHochladen,
            });

            expect(component.onStepChange).toHaveBeenCalledWith(BescheidWizardStep.DokumenteHochladen);
          });
        });
      });
    });

    describe('antrag bescheid step title', () => {
      it('should have inputs', () => {
        const stepTitleComponent: BescheidWizardStepTitleComponent =
          getElementComponentFromFixtureByCss<BescheidWizardStepTitleComponent>(fixture, antragBescheidenStepTitleTestId);

        expect(stepTitleComponent.inactiveStep).toEqual(true);
      });
    });

    describe('dokumente hochladen step title', () => {
      it('should have inputs', () => {
        const stepTitleComponent: BescheidWizardStepTitleComponent =
          getElementComponentFromFixtureByCss<BescheidWizardStepTitleComponent>(fixture, dokumenteHochladenStepTitleTestId);

        expect(stepTitleComponent.inactiveStep).toEqual(true);
      });
    });

    describe('bescheid versenden form', () => {
      it('should have inputs', () => {
        component.bescheidResource = createBescheidResource();

        fixture.detectChanges();
        const formComponent: BescheidWizardBescheidVersendenFormComponent =
          getElementComponentFromFixtureByCss<BescheidWizardBescheidVersendenFormComponent>(fixture, formTestId);

        expect(formComponent.bescheidResource).toEqual(component.bescheidResource);
      });

      describe('output', () => {
        describe('sendBy', () => {
          it('should call handler', () => {
            component.onSendBy = jest.fn();

            triggerEvent({ fixture, elementSelector: formTestId, name: 'sendBy', data: BescheidSendBy.MANUAL });

            expect(component.onSendBy).toHaveBeenCalledWith(BescheidSendBy.MANUAL);
          });
        });
      });
    });

    describe('bescheid versenden summary', () => {
      it('should exists', () => {
        fixture.detectChanges();

        existsAsHtmlElement(fixture, versendenSummaryTestId);
      });

      it('should have inputs', () => {
        const wizard: Wizard = createWizard();
        bescheidService.getWizard.mockReturnValue(of(wizard));
        createComponent();
        component.bescheidResource = bescheidResource;

        fixture.detectChanges();
        const summaryComponent: BescheidWizardBescheidVersendenSummaryComponent =
          getElementComponentFromFixtureByCss<BescheidWizardBescheidVersendenSummaryComponent>(fixture, versendenSummaryTestId);

        expect(summaryComponent.bescheidResource).toEqual(bescheidResource);
        expect(summaryComponent.wizard).toEqual(wizard);
      });
    });
  });
});
