import { BescheidDocument, createEmptyBescheidDocument } from '@alfa-client/bescheid-shared';
import { hasStateResourceError, isNotNil } from '@alfa-client/tech-shared';
import { Component, EventEmitter, Input, Output } from '@angular/core';

@Component({
  selector: 'alfa-bescheid-wizard-document-file',
  templateUrl: './bescheid-wizard-document-file.component.html',
})
export class BescheidWizardDocumentFileComponent {
  static readonly CREATE_ERROR_MESSAGE = 'Bescheiddokument konnte nicht erzeugt werden.';

  @Input() set bescheidDocument(value: BescheidDocument) {
    this.update(value);
  }

  get bescheidDocument(): BescheidDocument {
    return this._bescheidDocument;
  }

  @Input() public deletable: boolean;

  @Output() deleteFile: EventEmitter<void> = new EventEmitter<void>();

  public showAutomaticCreation: boolean = false;
  public showUpload: boolean = false;
  public showDocument: boolean = false;
  public createDocumentErrorMessages: string[] = [];

  private _bescheidDocument: BescheidDocument = createEmptyBescheidDocument();

  update(value: BescheidDocument) {
    this._bescheidDocument = value;
    this.showAutomaticCreation = value.create.loading || hasStateResourceError(value.create);
    this.showUpload = value.upload.loading || isNotNil(value.upload.error);
    this.showDocument = isNotNil(value.resource) && !value.upload.loading && !value.create.loading;
    this.createDocumentErrorMessages =
      hasStateResourceError(value.create) ? [BescheidWizardDocumentFileComponent.CREATE_ERROR_MESSAGE] : [];
  }
}
