import { BescheidAttachments, BescheidResource } from '@alfa-client/bescheid-shared';
import { getElementComponentFromFixtureByCss, Mock, mock, triggerEvent } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { MockComponent } from 'ng-mocks';
import { of } from 'rxjs';
import { BescheidService2 } from '../../../../../../bescheid-shared/src/lib/bescheid2.service';
import { createBescheidAttachments, createBescheidResource } from '../../../../../../bescheid-shared/src/test/bescheid';
import { getDataTestIdOf } from '../../../../../../tech-shared/test/data-test';
import { createFile } from '../../../../../../tech-shared/test/file';
import { singleColdCompleted } from '../../../../../../tech-shared/test/marbles';
import { BescheidWizardUploadAttachmentButtonContainerComponent } from './bescheid-wizard-upload-attachment-button-container.component';
import { BescheidWizardUploadAttachmentButtonComponent } from './upload-attachment-button/bescheid-wizard-upload-attachment-button.component';

describe('BescheidWizardUploadAttachmentButtonContainerComponent', () => {
  let component: BescheidWizardUploadAttachmentButtonContainerComponent;
  let fixture: ComponentFixture<BescheidWizardUploadAttachmentButtonContainerComponent>;

  const uploadAttachmentButtonTestId: string = getDataTestIdOf('upload-attachment-button');

  const bescheidAttachments: BescheidAttachments = createBescheidAttachments();

  let bescheidService: Mock<BescheidService2>;

  beforeEach(() => {
    bescheidService = mock(BescheidService2);
  });

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        BescheidWizardUploadAttachmentButtonContainerComponent,
        MockComponent(BescheidWizardUploadAttachmentButtonComponent),
      ],
      providers: [{ provide: BescheidService2, useValue: bescheidService }],
    }).compileComponents();

    createComponent();
  });

  function createComponent() {
    fixture = TestBed.createComponent(BescheidWizardUploadAttachmentButtonContainerComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  }

  describe('component', () => {
    it('should create', () => {
      expect(component).toBeTruthy();
    });

    it('should set initial values', () => {
      bescheidService.getAttachments.mockReturnValue(of(bescheidAttachments));

      createComponent();

      expect(component.attachments$).toBeObservable(singleColdCompleted(bescheidAttachments));
    });

    describe('uploadFile', () => {
      it('should call bescheid service', () => {
        const bescheidResource: BescheidResource = createBescheidResource();
        const file: File = createFile();
        component.bescheidResource = bescheidResource;

        component.uploadFile(file);

        expect(bescheidService.uploadAttachment).toHaveBeenCalledWith(file, bescheidResource);
      });
    });
  });

  describe('template', () => {
    describe('upload attachment button', () => {
      it('should have been called with inputs', () => {
        bescheidService.getAttachments.mockReturnValue(of(bescheidAttachments));
        createComponent();

        const uploadAttachmentButtonComponent: BescheidWizardUploadAttachmentButtonComponent =
          getElementComponentFromFixtureByCss<BescheidWizardUploadAttachmentButtonComponent>(
            fixture,
            uploadAttachmentButtonTestId,
          );

        expect(uploadAttachmentButtonComponent.attachments).toEqual(bescheidAttachments);
      });

      describe('output', () => {
        describe('uploadFile', () => {
          it('should call handler', () => {
            component.uploadFile = jest.fn();
            const file: File = createFile();

            triggerEvent({ fixture, elementSelector: uploadAttachmentButtonTestId, name: 'uploadFile', data: file });

            expect(component.uploadFile).toHaveBeenCalledWith(file);
          });
        });
      });
    });
  });
});
