/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { BescheidSharedModule } from '@alfa-client/bescheid-shared';
import { BinaryFileModule } from '@alfa-client/binary-file';
import { CommandSharedModule } from '@alfa-client/command-shared';
import {
  ConvertForDataTestPipe,
  ConvertProblemDetailToErrorMessagesPipe,
  GetUrlPipe,
  HasLinkPipe,
  ToEmbeddedResourcesPipe,
} from '@alfa-client/tech-shared';
import { CommonModule } from '@angular/common';
import { NgModule } from '@angular/core';
import {
  ButtonWithSpinnerComponent,
  FileUploadEditorComponent,
  SingleFileUploadEditorComponent,
  TextareaEditorComponent,
  TextEditorComponent,
} from '@ods/component';
import { BescheidInVorgangContainerComponent } from './bescheid-in-vorgang-container/bescheid-in-vorgang-container.component';
import { BescheidInVorgangComponent } from './bescheid-in-vorgang-container/bescheid-in-vorgang/bescheid-in-vorgang.component';
import { BescheidListInVorgangContainerComponent } from './bescheid-list-in-vorgang-container/bescheid-list-in-vorgang-container.component';
import { BescheidListInVorgangComponent } from './bescheid-list-in-vorgang-container/bescheid-list-in-vorgang/bescheid-list-in-vorgang.component';
import { DocumentInBescheidContainerComponent } from './bescheid-list-in-vorgang-container/bescheid-list-in-vorgang/document-in-bescheid-container/document-in-bescheid-container.component';
import { BeschiedenDateContainerComponent } from './beschieden-date-in-vorgang-container/beschieden-date-container/beschieden-date-container.component';
import { BeschiedenDateInVorgangContainerComponent } from './beschieden-date-in-vorgang-container/beschieden-date-in-vorgang-container.component';

import {
  DateEditorComponent,
  ExpansionPanelComponent,
  OzgcloudStrokedButtonWithSpinnerComponent,
  SpinnerComponent,
} from '@alfa-client/ui';
import { ReactiveFormsModule } from '@angular/forms';
import { MatIcon } from '@angular/material/icon';
import {
  AttachmentComponent,
  AttachmentWrapperComponent,
  BescheidGenerateIconComponent,
  BescheidStatusTextComponent,
  BescheidUploadIconComponent,
  BescheidWrapperComponent,
  ButtonCardComponent,
  ButtonComponent,
  CloseIconComponent,
  RadioButtonCardComponent,
  SaveIconComponent,
  SendIconComponent,
  SpinnerIconComponent,
  StampIconComponent,
} from '@ods/system';
import { FormatFullDatePipe } from '../../../tech-shared/src/lib/pipe/format-full-date.pipe';
import { BescheidWizardContainerComponent } from './bescheid-wizard-container/bescheid-wizard-container.component';
import { BescheidWizardAbschliessenButtonComponent } from './bescheid-wizard-container/bescheid-wizard/antrag-bescheiden/abschliessen-button/bescheid-wizard-abschliessen-button.component';
import { BescheidWizardAbschliessenDialogContainerComponent } from './bescheid-wizard-container/bescheid-wizard/antrag-bescheiden/abschliessen-dialog-container/bescheid-wizard-abschliessen-dialog-container.component';
import { BescheidWizardAntragBescheidenContainerComponent } from './bescheid-wizard-container/bescheid-wizard/antrag-bescheiden/bescheid-wizard-antrag-bescheiden-container.component';
import { BescheidWizardAntragBescheidenFormComponent } from './bescheid-wizard-container/bescheid-wizard/antrag-bescheiden/form/bescheid-wizard-antrag-bescheiden-form.component';
import { BescheidWizardAntragBescheidenSummaryComponent } from './bescheid-wizard-container/bescheid-wizard/antrag-bescheiden/summary/bescheid-wizard-antrag-bescheiden-summary.component';
import { BescheidWizardAttachmentFilesComponent } from './bescheid-wizard-container/bescheid-wizard/attachment-files-container/attachment-files/bescheid-wizard-attachment-files.component';
import { BescheidWizardAttachmentFilesContainerComponent } from './bescheid-wizard-container/bescheid-wizard/attachment-files-container/bescheid-wizard-attachment-files-container.component';
import { BescheidWizardBescheidVersendenContainerComponent } from './bescheid-wizard-container/bescheid-wizard/bescheid-versenden/bescheid-wizard-bescheid-versenden-container.component';
import { BescheidWizardBescheidVersendenFormComponent } from './bescheid-wizard-container/bescheid-wizard/bescheid-versenden/form/bescheid-wizard-bescheid-versenden-form.component';
import { BescheidWizardBescheidVersendenSummaryComponent } from './bescheid-wizard-container/bescheid-wizard/bescheid-versenden/summary/bescheid-wizard-bescheid-versenden-summary.component';
import { BescheidWizardBescheidVersendenSendenComponent } from './bescheid-wizard-container/bescheid-wizard/bescheid-versenden/summary/senden/bescheid-wizard-bescheid-versenden-senden.component';
import { BescheidWizardBescheidVersendenSpeichernComponent } from './bescheid-wizard-container/bescheid-wizard/bescheid-versenden/summary/speichern/bescheid-wizard-bescheid-versenden-speichern.component';
import { BescheidWizardComponent } from './bescheid-wizard-container/bescheid-wizard/bescheid-wizard.component';
import { BescheidWizardCancelDialogContainerComponent } from './bescheid-wizard-container/bescheid-wizard/cancel-dialog-container/bescheid-wizard-cancel-dialog-container.component';
import { BescheidWizardCreateDocumentButtonContainerComponent } from './bescheid-wizard-container/bescheid-wizard/create-document-button-container/bescheid-wizard-create-document-button-container.component';
import { BescheidWizardCreateDocumentButtonComponent } from './bescheid-wizard-container/bescheid-wizard/create-document-button-container/create-document-button/bescheid-wizard-create-document-button.component';
import { BescheidWizardDocumentFileContainerComponent } from './bescheid-wizard-container/bescheid-wizard/document-file-container/bescheid-wizard-document-file-container.component';
import { BescheidWizardDocumentFileComponent } from './bescheid-wizard-container/bescheid-wizard/document-file-container/document-file/bescheid-wizard-document-file.component';
import { BescheidWizardDokumenteHochladenContainerComponent } from './bescheid-wizard-container/bescheid-wizard/dokumente-hochladen-container/bescheid-wizard-dokumente-hochladen-container.component';
import { BescheidWizardDokumenteHochladenFormComponent } from './bescheid-wizard-container/bescheid-wizard/dokumente-hochladen-container/form/bescheid-wizard-dokumente-hochladen-form.component';
import { BescheidWizardDokumenteHochladenSummaryComponent } from './bescheid-wizard-container/bescheid-wizard/dokumente-hochladen-container/summary/bescheid-wizard-dokumente-hochladen-summary.component';
import { StepContentLayoutComponent } from './bescheid-wizard-container/bescheid-wizard/step-content-layout/step-content-layout.component';
import { BescheidWizardStepTitleComponent } from './bescheid-wizard-container/bescheid-wizard/step-title/bescheid-wizard-step-title.component';
import { BescheidWizardStepperComponent } from './bescheid-wizard-container/bescheid-wizard/stepper/bescheid-wizard-stepper.component';
import { BescheidWizardStepComponent } from './bescheid-wizard-container/bescheid-wizard/stepper/step/bescheid-wizard-step.component';
import { BescheidWizardSummaryComponent } from './bescheid-wizard-container/bescheid-wizard/summary/bescheid-wizard-summary.component';
import { BescheidWizardUploadAttachmentButtonContainerComponent } from './bescheid-wizard-container/bescheid-wizard/upload-attachment-button-container/bescheid-wizard-upload-attachment-button-container.component';
import { BescheidWizardUploadAttachmentButtonComponent } from './bescheid-wizard-container/bescheid-wizard/upload-attachment-button-container/upload-attachment-button/bescheid-wizard-upload-attachment-button.component';
import { BescheidWizardUploadDocumentButtonContainerComponent } from './bescheid-wizard-container/bescheid-wizard/upload-document-button-container/bescheid-wizard-upload-document-button-container.component';
import { BescheidWizardUploadDocumentButtonComponent } from './bescheid-wizard-container/bescheid-wizard/upload-document-button-container/upload-document-button/bescheid-wizard-upload-document-button.component';
import { BescheidWizardWeiterButtonComponent } from './bescheid-wizard-container/bescheid-wizard/weiter-button/bescheid-wizard-weiter-button.component';

@NgModule({
  imports: [
    CommonModule,
    BescheidSharedModule,
    BinaryFileModule,
    CommandSharedModule,
    BescheidStatusTextComponent,
    BescheidWrapperComponent,
    StampIconComponent,
    CloseIconComponent,
    ButtonWithSpinnerComponent,
    RadioButtonCardComponent,
    ButtonComponent,
    FormatFullDatePipe,
    HasLinkPipe,
    GetUrlPipe,
    ToEmbeddedResourcesPipe,
    SpinnerComponent,
    ExpansionPanelComponent,
    AttachmentWrapperComponent,
    MatIcon,
    DateEditorComponent,
    OzgcloudStrokedButtonWithSpinnerComponent,
    ReactiveFormsModule,
    ButtonCardComponent,
    BescheidGenerateIconComponent,
    SingleFileUploadEditorComponent,
    BescheidUploadIconComponent,
    SpinnerIconComponent,
    AttachmentComponent,
    AttachmentWrapperComponent,
    FileUploadEditorComponent,
    SendIconComponent,
    SaveIconComponent,
    TextEditorComponent,
    TextareaEditorComponent,
    ConvertForDataTestPipe,
    ConvertProblemDetailToErrorMessagesPipe,
  ],
  declarations: [
    BescheidInVorgangContainerComponent,
    BescheidInVorgangComponent,
    BescheidListInVorgangContainerComponent,
    BescheidListInVorgangComponent,
    DocumentInBescheidContainerComponent,
    BeschiedenDateContainerComponent,
    BeschiedenDateInVorgangContainerComponent,
    BescheidWizardContainerComponent,
    BescheidWizardComponent,
    BescheidWizardStepComponent,
    BescheidWizardStepperComponent,
    BescheidWizardStepTitleComponent,
    BescheidWizardSummaryComponent,
    BescheidWizardWeiterButtonComponent,
    BescheidWizardCancelDialogContainerComponent,
    BescheidWizardAntragBescheidenContainerComponent,
    BescheidWizardAntragBescheidenFormComponent,
    BescheidWizardAntragBescheidenSummaryComponent,
    BescheidWizardDokumenteHochladenContainerComponent,
    BescheidWizardDokumenteHochladenFormComponent,
    BescheidWizardDokumenteHochladenSummaryComponent,
    BescheidWizardAbschliessenButtonComponent,
    BescheidWizardAbschliessenDialogContainerComponent,
    BescheidWizardCreateDocumentButtonContainerComponent,
    BescheidWizardCreateDocumentButtonComponent,
    BescheidWizardUploadDocumentButtonComponent,
    BescheidWizardUploadDocumentButtonContainerComponent,
    BescheidWizardDocumentFileComponent,
    BescheidWizardDocumentFileContainerComponent,
    BescheidWizardDocumentFileComponent,
    BescheidWizardUploadAttachmentButtonContainerComponent,
    BescheidWizardUploadAttachmentButtonComponent,
    BescheidWizardAttachmentFilesContainerComponent,
    BescheidWizardAttachmentFilesComponent,
    BescheidWizardBescheidVersendenContainerComponent,
    BescheidWizardBescheidVersendenFormComponent,
    BescheidWizardBescheidVersendenSummaryComponent,
    BescheidWizardBescheidVersendenSendenComponent,
    BescheidWizardBescheidVersendenSpeichernComponent,
    StepContentLayoutComponent,
  ],
  exports: [
    BescheidInVorgangContainerComponent,
    BescheidListInVorgangContainerComponent,
    BeschiedenDateInVorgangContainerComponent,
  ],
})
export class BescheidModule {}
