/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { BinaryFileListResource, BinaryFileResource } from '@alfa-client/binary-file-shared';
import {
  StateResource,
  ToEmbeddedResourcesPipe,
  createStateResource,
} from '@alfa-client/tech-shared';
import { getMockComponent } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import {
  createBinaryFileListResource,
  createBinaryFileResource,
} from 'libs/binary-file-shared/test/binary-file';
import { MockComponent } from 'ng-mocks';
import { BinaryFile2ContainerComponent } from '../../binary-file2-container/binary-file2-container.component';
import { BinaryFileListComponent } from './binary-file-list.component';

describe('BinaryFileListComponent', () => {
  let component: BinaryFileListComponent;
  let fixture: ComponentFixture<BinaryFileListComponent>;

  const binaryFile: BinaryFileResource = createBinaryFileResource();
  const binaryFileListStateResource: StateResource<BinaryFileListResource> = createStateResource(
    createBinaryFileListResource([binaryFile]),
  );

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        BinaryFileListComponent,
        ToEmbeddedResourcesPipe,
        MockComponent(BinaryFile2ContainerComponent),
      ],
    }).compileComponents();

    fixture = TestBed.createComponent(BinaryFileListComponent);
    component = fixture.componentInstance;
    component.binaryFileListStateResource = binaryFileListStateResource;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('binary file container', () => {
    it('should be called with file', () => {
      const binaryFileContainerComponent: BinaryFile2ContainerComponent =
        getMockComponent<BinaryFile2ContainerComponent>(fixture, BinaryFile2ContainerComponent);

      expect(binaryFileContainerComponent.file).toBe(binaryFile);
    });

    it('should be called with deleteable', () => {
      const binaryFileContainerComponent: BinaryFile2ContainerComponent =
        getMockComponent<BinaryFile2ContainerComponent>(fixture, BinaryFile2ContainerComponent);

      expect(binaryFileContainerComponent.deletable).toBeFalsy();
    });
  });
});
