/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ApiDownloadToken, ApiRootService } from '@alfa-client/api-root-shared';
import { BinaryFileResource, BinaryFileService } from '@alfa-client/binary-file-shared';
import { StateResource } from '@alfa-client/tech-shared';
import { Component, EventEmitter, Input, Output } from '@angular/core';
import { Observable } from 'rxjs';

@Component({
  selector: 'alfa-binary-file2-container',
  templateUrl: './binary-file2-container.component.html',
})
export class BinaryFile2ContainerComponent {
  @Input() file: BinaryFileResource;
  @Input() downloadFileNamePrefix: string;
  @Input() deletable: boolean = false;

  @Output() startDelete: EventEmitter<BinaryFileResource> = new EventEmitter();

  fileStateResource$: Observable<StateResource<Blob>>;
  downloadToken$: Observable<ApiDownloadToken>;

  constructor(
    private binaryFileService: BinaryFileService,
    private apiRootService: ApiRootService,
  ) {}

  startDownload(file: BinaryFileResource): void {
    this.fileStateResource$ = this.binaryFileService.downloadFile(file, this.downloadFileNamePrefix);
  }

  getDownloadToken(): void {
    this.downloadToken$ = this.apiRootService.getDownloadToken(this.file);
  }
}
