/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { CommandResource } from '@alfa-client/command-shared';
import { ForwardingListResource, ForwardingService } from '@alfa-client/forwarding-shared';
import { createEmptyStateResource, StateResource } from '@alfa-client/tech-shared';
import { VorgangWithEingangLinkRel, VorgangWithEingangResource } from '@alfa-client/vorgang-shared';
import { Component, Input, OnChanges } from '@angular/core';
import { hasLink } from '@ngxp/rest';
import { CommandLinkRel } from 'libs/command-shared/src/lib/command.linkrel';
import { Observable, of } from 'rxjs';
import { VorgangForwardFormService } from './vorgang-forward-formular/vorgang-forward-form/vorgang-forward.formservice';

@Component({
  selector: 'alfa-vorgang-forwarding-container',
  templateUrl: './vorgang-forwarding-container.component.html',
  styleUrls: ['./vorgang-forwarding-container.component.scss'],
  providers: [VorgangForwardFormService],
})
export class VorgangForwardingContainerComponent implements OnChanges {
  @Input() public vorgang: VorgangWithEingangResource;

  forwardingStateResources$: Observable<StateResource<ForwardingListResource>> =
    of(createEmptyStateResource<ForwardingListResource>());
  pendingForwardStateResource$: Observable<StateResource<CommandResource>> = of(createEmptyStateResource<CommandResource>());

  readonly linkRel = CommandLinkRel;
  readonly vorgangLinkRel = VorgangWithEingangLinkRel;

  constructor(
    public formService: VorgangForwardFormService,
    private forwardingService: ForwardingService,
  ) {}

  ngOnChanges(): void {
    this.updateVorgang();

    this.getForwardings();
    this.getPendingForwardCommand();
  }

  updateVorgang(): void {
    this.formService.setVorgang(this.vorgang);
  }

  getForwardings(): void {
    if (hasLink(this.vorgang, VorgangWithEingangLinkRel.FORWARD_BY_EMAIL)) {
      this.forwardingStateResources$ = this.forwardingService.getForwardings(this.vorgang);
    }
  }

  getPendingForwardCommand(): void {
    this.pendingForwardStateResource$ = this.forwardingService.getPendingForwardCommand();
  }

  submit(): void {
    this.pendingForwardStateResource$ = <Observable<StateResource<CommandResource>>>this.formService.submit();
  }
}
