/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { UserProfileResource } from '@alfa-client/user-profile-shared';
import { MockComponent } from 'ng-mocks';
import { createUserProfileResource } from '../../../../../../../user-profile-shared/test/user-profile';
import { HistorieItemHeaderComponent } from '../../historie-item-header/historie-item-header.component';
import { HistorieItemAssignUserComponent } from './historie-item-assign-user.component';

describe('HistorieItemAssignUserComponent', () => {
  let component: HistorieItemAssignUserComponent;
  let fixture: ComponentFixture<HistorieItemAssignUserComponent>;

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [HistorieItemAssignUserComponent, MockComponent(HistorieItemHeaderComponent)],
    }).compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(HistorieItemAssignUserComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('build headline', () => {
    it('should return "Unbekannter Benutzer" on user profile is null', () => {
      const headline: string = component.buildHeadline(null);

      expect(headline).toBe('Unbekannter Benutzer den Vorgang zugewiesen.');
    });

    it('should return firstName lastName on user profile exists', () => {
      const userProfile: UserProfileResource = createUserProfileResource();

      const headline: string = component.buildHeadline(userProfile);

      expect(headline).toBe(
        `${userProfile.firstName} ${userProfile.lastName} den Vorgang zugewiesen.`,
      );
    });
  });
});
