/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ApiError, getMessageForIssue } from '@alfa-client/tech-shared';
import { createApiError } from '../../../test/error';
import { ConvertApiErrorToErrorMessagesPipe } from './convert-api-error-to-error-messages.pipe';

jest.mock('@alfa-client/tech-shared');
const getMessageForIssueMock = getMessageForIssue as jest.Mock;

describe('convertApiErrorToErrorMessagesPipe', () => {
  const pipe = new ConvertApiErrorToErrorMessagesPipe();

  it('create an instance', () => {
    expect(pipe).toBeTruthy();
  });

  describe('transform', () => {
    it.each([null, undefined])('should return empty array for %s value', (value: ApiError) => {
      const errorMessages: string[] = pipe.transform(value);

      expect(errorMessages).toEqual([]);
    });

    it('should get message for issue', () => {
      pipe.transform(createApiError());

      expect(getMessageForIssueMock).toHaveBeenCalled();
    });

    it('should return array of error messages', () => {
      const expectedErrorMessage = 'Fehler';
      getMessageForIssueMock.mockReturnValue(expectedErrorMessage);

      const errorMessages: string[] = pipe.transform(createApiError());

      expect(errorMessages).toEqual([expectedErrorMessage]);
    });
  });
});
