import { Mock, mock, mockGetValue } from '@alfa-client/test-utils';
import { ApplicationRef, ComponentRef, EnvironmentInjector, Injector, ViewRef } from '@angular/core';
import { TestBed } from '@angular/core/testing';
import { OzgCloudComponentFactory } from './component.factory';

import { ComponentType } from '@angular/cdk/portal';

jest.mock('@angular/core', () => ({
  ...jest.requireActual('@angular/core'),
  createComponent: jest.fn(),
}));

describe('OzgCloudComponentFactory', () => {
  let factory: OzgCloudComponentFactory;

  let appRef: Mock<ApplicationRef>;
  let envInjector: Mock<EnvironmentInjector>;

  beforeEach(() => {
    appRef = mock(ApplicationRef);
    envInjector = mock(EnvironmentInjector as any);

    factory = TestBed.inject(OzgCloudComponentFactory);

    mockGetValue(factory, 'appRef', appRef);
    mockGetValue(factory, 'envInjector', envInjector);
  });

  it('should be created', () => {
    expect(factory).toBeTruthy();
  });

  describe('create component', () => {
    let createComponentSpy: jest.SpyInstance;
    const injectorMock: Mock<Injector> = mock(Injector as any);
    const componentRefMock: Mock<ComponentRef<any>> = mock(ComponentRef as any);

    const componentType: ComponentType<any> = <any>{};
    const injector: Injector = <any>{};

    beforeEach(() => {
      createComponentSpy = jest.spyOn(require('@angular/core'), 'createComponent').mockReturnValue(componentRefMock);
      factory._createElementInjector = jest.fn().mockReturnValue(injectorMock);
      factory._registerComponentToChangeDetection = jest.fn();
    });

    it('should call createComponent', () => {
      factory.createComponent(componentType, injector);

      expect(createComponentSpy).toHaveBeenCalledWith(componentType, {
        environmentInjector: envInjector,
        elementInjector: injectorMock,
      });
    });

    it('should register component to angulars change detection', () => {
      factory.createComponent(componentType, injector);

      expect(factory._registerComponentToChangeDetection).toHaveBeenCalledWith(componentRefMock);
    });

    it('should return created component', () => {
      const componentRef: ComponentRef<any> = factory.createComponent(componentType, injector);

      expect(componentRef).toBe(componentRefMock);
    });
  });

  describe('create element injector', () => {
    const injectorMock: Mock<Injector> = mock(Injector as any);

    let createSpy: jest.SpyInstance;

    beforeEach(() => {
      createSpy = jest.spyOn(Injector, 'create').mockReturnValue(injectorMock as Injector);
    });

    it('should create an injector by given parent selector', () => {
      factory._createElementInjector(injectorMock);

      expect(createSpy).toHaveBeenCalled();
    });

    it('should return created injector', () => {
      const injector: Injector = factory._createElementInjector(injectorMock);

      expect(injector).toBe(injectorMock);
    });
  });

  describe('register component to angulars change detection', () => {
    const hostView: ViewRef = <any>{};
    const componentRef: ComponentRef<any> = <any>{ hostView };

    it('should set hostview to appRef', () => {
      factory._registerComponentToChangeDetection(componentRef);

      expect(appRef.attachView).toHaveBeenCalledWith(hostView);
    });
  });
});
