/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { mock } from '@alfa-client/test-utils';
import { UserProfileService } from '@alfa-client/user-profile-shared';
import { VorgangHeaderLinkRel, VorgangWithEingangResource } from '@alfa-client/vorgang-shared';
import { createVorgangWithEingangResource } from 'libs/vorgang-shared/test/vorgang';
import { MockComponent } from 'ng-mocks';
import { BehaviorSubject } from 'rxjs';
import { UserProfileInVorgangContainerComponent } from './user-profile-in-vorgang-container.component';
import { UserProfileInVorgangComponent } from './user-profile-in-vorgang/user-profile-in-vorgang.component';

describe('UserProfileInVorgangContainerComponent', () => {
  let component: UserProfileInVorgangContainerComponent;
  let fixture: ComponentFixture<UserProfileInVorgangContainerComponent>;

  const visibilitySubj: BehaviorSubject<boolean> = new BehaviorSubject(false);
  const userProfileService = {
    ...mock(UserProfileService),
    isUserProfileSearchVisible: () => visibilitySubj,
  };

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        UserProfileInVorgangContainerComponent,
        MockComponent(UserProfileInVorgangComponent),
      ],
      providers: [
        {
          provide: UserProfileService,
          useValue: userProfileService,
        },
      ],
    });
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(UserProfileInVorgangContainerComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('ngOnChanges', () => {
    it('should call userProfileService if link is present', () => {
      const vorgang: VorgangWithEingangResource = createVorgangWithEingangResource([
        VorgangHeaderLinkRel.ASSIGNED_TO,
      ]);
      component.vorgang = vorgang;

      component.ngOnChanges({ vorgang: <any>{} });

      expect(userProfileService.getAssignedUserProfile).toHaveBeenCalledWith(
        vorgang,
        VorgangHeaderLinkRel.ASSIGNED_TO,
      );
    });

    it('should NOT call userProfileService', () => {
      component.vorgang = createVorgangWithEingangResource();

      component.ngOnChanges({ vorgang: <any>{} });

      expect(userProfileService.getAssignedUserProfile).not.toHaveBeenCalledWith();
    });
  });
});
