/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { AppService } from '@alfa-client/app-shared';
import { mock } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { MockComponent } from 'ng-mocks';
import { BehaviorSubject } from 'rxjs';
import { UserSettingsDarkmodeContainerComponent } from './user-settings-darkmode-container.component';
import { UserSettingsDarkmodeComponent } from './user-settings-darkmode/user-settings-darkmode.component';

describe('UserSettingsDarkmodeContainerComponent', () => {
  let component: UserSettingsDarkmodeContainerComponent;
  let fixture: ComponentFixture<UserSettingsDarkmodeContainerComponent>;

  const darkModeSubj: BehaviorSubject<boolean> = new BehaviorSubject(false);
  const appService = { ...mock(AppService), getDarkMode: () => darkModeSubj };

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        UserSettingsDarkmodeContainerComponent,
        MockComponent(UserSettingsDarkmodeComponent),
      ],
      providers: [
        {
          provide: AppService,
          useValue: appService,
        },
      ],
    }).compileComponents();

    fixture = TestBed.createComponent(UserSettingsDarkmodeContainerComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('change color mode', () => {
    it('should call app service', () => {
      component.changeColorMode(true);

      expect(appService.setDarkMode).toHaveBeenCalledWith(true);
    });
  });
});
