/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ForwardByOzgcloudButtonContainerComponent } from '@alfa-client/forwarding';
import {
  EndgueltigLoeschenButtonContainerComponent,
  LoeschAnforderungZuruecknehmenButtonContainerComponent,
  LoeschenAnfordernButtonContainerComponent,
} from '@alfa-client/loesch-anforderung';
import { HasLinkPipe } from '@alfa-client/tech-shared';
import { existsAsHtmlElement, getMockComponent, notExistsAsHtmlElement } from '@alfa-client/test-utils';
import { OzgcloudStrokedButtonWithSpinnerComponent } from '@alfa-client/ui';
import { VorgangWithEingangLinkRel, VorgangWithEingangResource } from '@alfa-client/vorgang-shared';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { getDataTestIdOf } from 'libs/tech-shared/test/data-test';
import { createVorgangWithEingangResource } from 'libs/vorgang-shared/test/vorgang';
import { MockComponent } from 'ng-mocks';
import { AbschliessenButtonComponent } from '../../../buttons/abschliessen-button/abschliessen-button.component';
import { AnnehmenButtonComponent } from '../../../buttons/annehmen-button/annehmen-button.component';
import { BearbeitenButtonComponent } from '../../../buttons/bearbeiten-button/bearbeiten-button.component';
import { BescheidenButtonComponent } from '../../../buttons/bescheiden-button/bescheiden-button.component';
import { VerwerfenButtonComponent } from '../../../buttons/verwerfen-button/verwerfen-button.component';
import { WiedereroeffnenButtonComponent } from '../../../buttons/wiedereroeffnen-button/wiedereroeffnen-button.component';
import { ZurueckholenButtonComponent } from '../../../buttons/zurueckholen-button/zurueckholen-button.component';
import { ZurueckstellenButtonComponent } from '../../../buttons/zurueckstellen-button/zurueckstellen-button.component';
import { VorgangDetailFormularButtonsComponent } from './vorgang-detail-formular-buttons.component';

describe('VorgangDetailFormularButtonsComponent', () => {
  let component: VorgangDetailFormularButtonsComponent;
  let fixture: ComponentFixture<VorgangDetailFormularButtonsComponent>;

  const loeschenAnfordernButtonContainer: string = getDataTestIdOf('loeschen-anfordern-button-container');

  const vorgangWithEingang: VorgangWithEingangResource = createVorgangWithEingangResource();

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        VorgangDetailFormularButtonsComponent,
        HasLinkPipe,
        MockComponent(OzgcloudStrokedButtonWithSpinnerComponent),
        MockComponent(AnnehmenButtonComponent),
        MockComponent(BearbeitenButtonComponent),
        MockComponent(VerwerfenButtonComponent),
        MockComponent(ZurueckholenButtonComponent),
        MockComponent(BescheidenButtonComponent),
        MockComponent(AbschliessenButtonComponent),
        MockComponent(ZurueckstellenButtonComponent),
        MockComponent(WiedereroeffnenButtonComponent),
        MockComponent(LoeschenAnfordernButtonContainerComponent),
        MockComponent(EndgueltigLoeschenButtonContainerComponent),
        MockComponent(LoeschAnforderungZuruecknehmenButtonContainerComponent),
        MockComponent(ForwardByOzgcloudButtonContainerComponent),
      ],
    });
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(VorgangDetailFormularButtonsComponent);
    component = fixture.componentInstance;
    component.vorgangWithEingang = vorgangWithEingang;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('loeschenAnfordernButtonContainer', () => {
    it('should show if link is present', () => {
      component.vorgangWithEingang = createVorgangWithEingangResource([VorgangWithEingangLinkRel.LOESCHEN_ANFORDERN]);
      fixture.detectChanges();

      existsAsHtmlElement(fixture, loeschenAnfordernButtonContainer);
    });

    it('should hide if link is not present', () => {
      component.vorgangWithEingang = vorgangWithEingang;
      fixture.detectChanges();

      notExistsAsHtmlElement(fixture, loeschenAnfordernButtonContainer);
    });
  });

  it('forwarding button should be called', () => {
    component.vorgangWithEingang = vorgangWithEingang;
    fixture.detectChanges();

    const button: ForwardByOzgcloudButtonContainerComponent = getMockComponent(
      fixture,
      ForwardByOzgcloudButtonContainerComponent,
    );
    expect(button.vorgangWithEingang).toBe(vorgangWithEingang);
  });
});
