/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { BescheidLinkRel, BescheidResource, BescheidService } from '@alfa-client/bescheid-shared';
import { CommandResource, isSuccessfulDone } from '@alfa-client/command-shared';
import { createEmptyStateResource, StateResource } from '@alfa-client/tech-shared';
import { Component, Input } from '@angular/core';
import { Observable, of, tap } from 'rxjs';
import { BescheidenFormService } from '../../../../bescheiden.formservice';

@Component({
  selector: 'alfa-vorgang-detail-bescheiden-bescheid-automatisch-erstellen',
  templateUrl: './vorgang-detail-bescheiden-bescheid-automatisch-erstellen.component.html',
})
export class VorgangDetailBescheidenBescheidAutomatischErstellenComponent {
  @Input() public bescheidDraftStateResource: StateResource<BescheidResource>;

  public createBescheidDocumentInProgress$: Observable<StateResource<CommandResource>> = of(
    createEmptyStateResource<CommandResource>(),
  );

  public readonly bescheidLinkRel = BescheidLinkRel;

  constructor(
    private readonly bescheidService: BescheidService,
    private readonly formService: BescheidenFormService,
  ) {}

  public createBescheidDocument(): void {
    this.createBescheidDocumentInProgress$ = this.bescheidService.createBescheidDocument().pipe(
      tap((commandStateResource: StateResource<CommandResource>) => {
        if (isSuccessfulDone(commandStateResource.resource)) {
          this.formService.clearNachricht();
        }
      }),
    );
  }
}
