/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { BescheidService } from '@alfa-client/bescheid-shared';
import { HasLinkPipe } from '@alfa-client/tech-shared';
import { Mock, mock, useFromMock } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { ReactiveFormsModule, UntypedFormBuilder } from '@angular/forms';
import { MatIcon } from '@angular/material/icon';
import { faker } from '@faker-js/faker';
import { ResourceUri } from '@ngxp/rest';
import { SingleFileUploadEditorComponent } from '@ods/component';
import { SpinnerIconComponent } from '@ods/system';
import { MockComponent, MockPipe } from 'ng-mocks';
import { of } from 'rxjs';
import { createBescheidStateResource } from '../../../../../../../../../bescheid-shared/src/test/bescheid';
import { createFile } from '../../../../../../../../../tech-shared/test/file';
import { BescheidenFormService } from '../../../../bescheiden.formservice';
import { VorgangDetailBescheidenDokumentHochladenComponent } from './vorgang-detail-bescheiden-dokument-hochladen.component';

describe('VorgangDetailBescheidenDokumentHochladenComponent', () => {
  let component: VorgangDetailBescheidenDokumentHochladenComponent;
  let fixture: ComponentFixture<VorgangDetailBescheidenDokumentHochladenComponent>;

  let bescheidService: Mock<BescheidService>;
  let formService: BescheidenFormService;

  beforeEach(async () => {
    bescheidService = mock(BescheidService);
    bescheidService.getDocumentUri.mockReturnValue(of(null));

    formService = new BescheidenFormService(new UntypedFormBuilder(), useFromMock(bescheidService));

    await TestBed.configureTestingModule({
      declarations: [
        VorgangDetailBescheidenDokumentHochladenComponent,
        MatIcon,
        MockPipe(HasLinkPipe),
        MockComponent(SingleFileUploadEditorComponent),
        MockComponent(SpinnerIconComponent),
      ],
      imports: [ReactiveFormsModule],
      providers: [
        {
          provide: BescheidenFormService,
          useValue: formService,
        },
        {
          provide: BescheidService,
          useValue: bescheidService,
        },
      ],
    }).compileComponents();

    fixture = TestBed.createComponent(VorgangDetailBescheidenDokumentHochladenComponent);
    component = fixture.componentInstance;
    component.bescheidDraftStateResource = createBescheidStateResource();
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('ngOnInit', () => {
    it('should handle document uri changes', () => {
      bescheidService.getDocumentUri.mockReturnValue(of('DocumentUriDummy'));
      component.handleDocumentUriChanges = jest.fn();

      component.ngOnInit();

      expect(component.handleDocumentUriChanges).toHaveBeenCalledWith('DocumentUriDummy');
    });
  });

  describe('handle document uri changes', () => {
    it('should update bescheid document file in form service', () => {
      const documentUri: ResourceUri = faker.person.firstName();
      formService.updateBescheidDocumentFile = jest.fn();

      component.handleDocumentUriChanges(documentUri);

      expect(formService.updateBescheidDocumentFile).toHaveBeenCalledWith(documentUri);
    });
    it('should clear bescheid document file in form service', () => {
      formService.clearBescheidDocumentFile = jest.fn();

      component.handleDocumentUriChanges(null);

      expect(formService.clearBescheidDocumentFile).toHaveBeenCalled();
    });
  });

  describe('upload file', () => {
    it('should call service to upload bescheid document', () => {
      const bescheidStateResource = createBescheidStateResource();
      const file = createFile();
      component.bescheidDraftStateResource = bescheidStateResource;

      component.uploadFile(file);

      expect(bescheidService.uploadBescheidDocument).toHaveBeenCalledWith(bescheidStateResource.resource, file);
    });
  });
});
