/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { TestBed } from '@angular/core/testing';
import {
  ActivatedRouteSnapshot,
  CanActivateFn,
  RouterStateSnapshot,
  UrlSegment,
} from '@angular/router';
import { AuthService } from '@alfa-client/app-shared';
import { mock } from '@alfa-client/test-utils';
import { VorgangService } from '@alfa-client/vorgang-shared';
import { Observable, of } from 'rxjs';

import * as RouterHelper from '@angular/router';
import * as Guard from './vorgang-filter-view.guard';

jest.mock('@angular/router', () => mockAsEsModule('@angular/router'));

const next: ActivatedRouteSnapshot = {} as unknown as ActivatedRouteSnapshot;
const state: RouterStateSnapshot = {
  root: { url: [<UrlSegment>{}] },
} as unknown as RouterStateSnapshot;

function mockAsEsModule(module: string) {
  return {
    __esModule: true,
    ...jest.requireActual(module),
  };
}

describe('vorgangFilterViewGuard', () => {
  const vorgangService = mock(VorgangService);
  const authService = mock(AuthService);

  beforeEach(() => {
    TestBed.configureTestingModule({
      providers: [
        {
          provide: VorgangService,
          useValue: vorgangService,
        },
        {
          provide: AuthService,
          useValue: authService,
        },
      ],
    });

    jest.spyOn(vorgangService, 'canNavigateToPathSegements').mockReturnValue(of(false));
  });

  it('should be created', () => {
    const guard = TestBed.runInInjectionContext(() =>
      Guard.vorgangFilterViewGuard(next, state),
    ) as unknown as CanActivateFn;

    expect(guard).toBeTruthy();
  });

  describe('vorgangFilterViewGuard', () => {
    it('should call authService.hasNoValidToken', () => {
      const spy = jest.spyOn(authService, 'hasNoValidToken');

      TestBed.runInInjectionContext(() =>
        Guard.vorgangFilterViewGuard(next, state),
      ) as unknown as CanActivateFn;

      expect(spy).toHaveBeenCalled();
    });

    describe('access token is valid', () => {
      beforeEach(() => {
        jest.spyOn(authService, 'hasNoValidToken').mockReturnValue(false);
      });

      it('should call vorgangService.canNavigateToPathSegements', () => {
        const spy = jest.spyOn(vorgangService, 'canNavigateToPathSegements');

        TestBed.runInInjectionContext(() =>
          Guard.vorgangFilterViewGuard(next, state),
        ) as unknown as CanActivateFn;

        expect(spy).toHaveBeenCalled();
      });

      it('should call createUrlTreeFromSnapshot', () => {
        const createUrlTreeFromSnapshot = jest.spyOn(RouterHelper, 'createUrlTreeFromSnapshot');
        jest.spyOn(vorgangService, 'canNavigateToPathSegements').mockReturnValue(of(false));

        TestBed.runInInjectionContext(() =>
          (
            Guard.vorgangFilterViewGuard(next, state) as Observable<RouterHelper.UrlTree>
          ).subscribe(),
        ) as unknown as CanActivateFn;

        expect(createUrlTreeFromSnapshot).toHaveBeenCalled();
      });

      it.skip('should return UrlTree', (done) => {
        jest.spyOn(vorgangService, 'canNavigateToPathSegements').mockReturnValue(of(false));

        TestBed.runInInjectionContext(() =>
          (Guard.vorgangFilterViewGuard(next, state) as Observable<RouterHelper.UrlTree>).subscribe(
            (result) => {
              expect(result).toBeInstanceOf(RouterHelper.UrlTree);
              done();
            },
          ),
        ) as unknown as CanActivateFn;
      });

      it('should return true', (done) => {
        jest.spyOn(vorgangService, 'canNavigateToPathSegements').mockReturnValue(of(true));

        TestBed.runInInjectionContext(() =>
          (Guard.vorgangFilterViewGuard(next, state) as Observable<RouterHelper.UrlTree>).subscribe(
            (result) => {
              expect(result).toBeTruthy();
              done();
            },
          ),
        ) as unknown as CanActivateFn;
      });
    });

    describe('access token is not valid', () => {
      beforeEach(() => {
        jest.spyOn(authService, 'hasNoValidToken').mockReturnValue(true);
      });

      it('should return true', () => {
        const result = TestBed.runInInjectionContext(() =>
          Guard.vorgangFilterViewGuard(next, state),
        ) as unknown as CanActivateFn;

        expect(result).toBeTruthy();
      });
    });
  });
});
