/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { CommandResource } from '@alfa-client/command-shared';
import { NavigationService } from '@alfa-client/navigation-shared';
import { StateResource, createStateResource } from '@alfa-client/tech-shared';
import { mock } from '@alfa-client/test-utils';
import { OzgcloudStrokedButtonWithSpinnerComponent } from '@alfa-client/ui';
import { WiedervorlageService } from '@alfa-client/wiedervorlage-shared';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { ActivatedRoute } from '@angular/router';
import { ButtonWithSpinnerComponent } from '@ods/component';
import { SaveIconComponent } from '@ods/system';
import { CommandLinkRel } from 'libs/command-shared/src/lib/command.linkrel';
import { createCommandResource } from 'libs/command-shared/test/command';
import { MockComponent } from 'ng-mocks';
import { WiedervorlageFormService } from '../wiedervorlage-page-container/wiedervorlage-page/wiedervorlage-form/wiedervorlage.formservice';
import { SubmitWiedervorlageButtonComponent } from './submit-wiedervorlage-button.component';

describe('SubmitWiedervorlageButtonComponent', () => {
  let component: SubmitWiedervorlageButtonComponent;
  let fixture: ComponentFixture<SubmitWiedervorlageButtonComponent>;

  const wiedervorlageService = mock(WiedervorlageService);
  const navigationService = mock(NavigationService);
  const wiedervorlageFormService = mock(WiedervorlageFormService);
  const activatedRoute = mock(ActivatedRoute);

  const commandWithError: StateResource<CommandResource> = createStateResource(
    createCommandResource([CommandLinkRel.EFFECTED_RESOURCE]),
  );

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        SubmitWiedervorlageButtonComponent,
        MockComponent(OzgcloudStrokedButtonWithSpinnerComponent),
        MockComponent(ButtonWithSpinnerComponent),
        MockComponent(SaveIconComponent),
      ],
      providers: [
        {
          provide: WiedervorlageService,
          useValue: wiedervorlageService,
        },
        {
          provide: WiedervorlageFormService,
          useValue: wiedervorlageFormService,
        },
        {
          provide: NavigationService,
          useValue: navigationService,
        },
        {
          provide: ActivatedRoute,
          useValue: activatedRoute,
        },
      ],
    });
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(SubmitWiedervorlageButtonComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('navigateIfCommandIsDone', () => {
    it('should navigate on success', () => {
      component.navigateIfCommandIsDone(commandWithError);

      expect(navigationService.navigateRelativeTo).toHaveBeenCalled();
    });

    it('should NOT navigate on loading', () => {
      component.navigateIfCommandIsDone({ ...commandWithError, loading: true });

      expect(navigationService.navigateRelativeTo).toHaveBeenCalledWith('../../', activatedRoute);
    });
  });
});
